@@ -1,6 +1,6 @@
 /*
  * Argus Software.  Argus files - Modeler
- * Copyright (c) 2000-2015 QoSient, LLC
+ * Copyright (c) 2000-2020 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,12 +22,8 @@
  *
  */
 
-/* 
- * $Id: //depot/argus/argus/argus/ArgusNetflow.h#1 $
- * $DateTime: 2011/01/26 17:21:20 $
- * $Change: 2089 $
- */
-
+#ifndef ArgusNetflow_h
+#define ArgusNetflow_h
 
 #define CISCO_VERSION_1         1
 #define CISCO_VERSION_5         5
@@ -59,3 +55,4 @@ extern void ArgusParseCiscoRecordV7 (struct ArgusModelerStruct *, void *);
 extern void ArgusParseCiscoRecordV8 (struct ArgusModelerStruct *, void *);
 extern void ArgusParseCiscoRecordV9 (struct ArgusModelerStruct *, void *);
 #endif
+#endif
