@@ -1,6 +1,6 @@
 /*
  * Argus Software.  Argus files - Modeler
- * Copyright (c) 2000-2015 QoSient, LLC
+ * Copyright (c) 2000-2020 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -22,11 +22,6 @@
  *
  */
 
-/*
- * $Id: //depot/argus/argus/argus/ArgusOutput.c#81 $
- * $DateTime: 2015/04/06 10:38:44 $
- * $Change: 2973 $
- */
 
 #ifdef HAVE_CONFIG_H
 #include "argus_config.h"
@@ -1111,6 +1106,8 @@ ArgusCheckClientStatus (struct ArgusOutputStruct *output, int s)
                   ArgusLog (LOG_ERR, "ArgusCheckClientStatus: ArgusGenerateInitialMar error %s", strerror(errno));
 
 #ifdef ARGUS_SASL
+               if (ArgusMaxSsf == 0)
+                  goto no_auth;
 #ifdef ARGUSDEBUG
                ArgusDebug (2, "ArgusCheckClientStatus: SASL enabled\n");
 #endif
@@ -1188,6 +1185,7 @@ ArgusCheckClientStatus (struct ArgusOutputStruct *output, int s)
                }
 
                output->ArgusInitMar->argus_mar.status |= htonl(ARGUS_SASL_AUTHENTICATE);
+no_auth:
 #endif
                len = ntohs(output->ArgusInitMar->hdr.len) * 4;
 
@@ -1214,6 +1212,7 @@ ArgusCheckClientStatus (struct ArgusOutputStruct *output, int s)
                   }
 
                } else {
+                  ArgusAddToQueue(output->ArgusClients, &client->qhdr, ARGUS_NOLOCK);
                }
 #else
                ArgusAddToQueue(output->ArgusClients, &client->qhdr, ARGUS_NOLOCK);
