@@ -1,6 +1,6 @@
 /*
  * Argus Software.  Argus files - Input includes
- * Copyright (c) 2000-2015 QoSient, LLC
+ * Copyright (c) 2000-2020 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,13 +19,6 @@
  *
  */
 
-/*
- * $Id: //depot/argus/argus/argus/ArgusSource.h#47 $
- * $DateTime: 2015/04/13 00:43:29 $
- * $Change: 2982 $
- */
-
-/*  ArgusSource.h */
 
 #ifndef ArgusSource_h
 #define ArgusSource_h
@@ -760,6 +753,7 @@ void ArgusParseSourceID (struct ArgusSourceStruct *, char *);
 int ArgusSnoopRead (struct ArgusSourceStruct *);
 
 void ArgusIpPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
+void ArgusPflogPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
 void ArgusArcnetPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
 void ArgusEtherPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
 void ArgusTokenPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
@@ -824,6 +818,7 @@ void setArgusInterfaceType(struct ArgusSourceStruct *, unsigned char);
 unsigned char getArgusInterfaceStatus(struct ArgusSourceStruct *);
 void setArgusInterfaceStatus(struct ArgusSourceStruct *, unsigned char);
 
+int setArgusListInterfaces (struct ArgusSourceStruct *, int);
 
 #if defined(ArgusSource)
 
@@ -840,6 +835,7 @@ static struct callback ArgusSourceCallbacks[] = {
    { ArgusFddiPacket,      DLT_FDDI,        "ArgusFddiPacket()" },
    { ArgusATMPacket,       DLT_ATM_RFC1483, "ArgusATMPacket()" },
    { ArgusIpPacket,        DLT_RAW,         "ArgusIpPacket()" },
+   { ArgusPflogPacket,     DLT_PFLOG,       "ArgusPflogPacket()" },
    { ArgusNullPacket,      DLT_NULL,        "ArgusNullPacket()" },
 #ifdef DLT_ENC
    { ArgusEncPacket,       DLT_ENC,         "ArgusEncPacket()" },
