@@ -1,6 +1,6 @@
 /*
  * Argus Software.  Argus files - TCP protocol
- * Copyright (c) 2000-2015 QoSient, LLC
+ * Copyright (c) 2000-2020 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,11 +19,6 @@
  *
  */
 
-/* 
- * $Id: //depot/argus/argus/argus/ArgusTcp.c#51 $
- * $DateTime: 2015/07/02 10:42:46 $
- * $Change: 3030 $
- */
 
 #ifdef HAVE_CONFIG_H
 #include "argus_config.h"
@@ -225,10 +220,8 @@ ArgusUpdateTCPState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *f
 
          if (model->ArgusThisDir) {
             ArgusThisTCPsrc = &tcpExt->src;
-            ArgusThisTCPdst = &tcpExt->dst;
          } else {
             ArgusThisTCPsrc = &tcpExt->dst;
-            ArgusThisTCPdst = &tcpExt->src;
          }
 
          switch (tcpExt->state) {
@@ -527,7 +520,7 @@ ArgusUpdateTCPSequence (struct ArgusModelerStruct *model, struct ArgusFlowStruct
    unsigned int seq = tcp->th_seq;
    unsigned int newseq = seq + len;
    struct ArgusIPAttrStruct *attr = NULL;
-   unsigned short ipid = 0, *tipid;
+   unsigned short ipid = 0, *tipid = NULL;
 
    if (model->ArgusThisDir) {
       ArgusThisTCPsrc = &tcpExt->src;
@@ -622,7 +615,7 @@ ArgusUpdateTCPSequence (struct ArgusModelerStruct *model, struct ArgusFlowStruct
 
                      if (ArgusThisTCPsrc->win) {
                         int dipid;
-                        if (*tipid && ((dipid = (ipid - *tipid)) < 0) && (dipid > -5000)) {
+                        if (tipid && ((dipid = (ipid - *tipid)) < 0) && (dipid > -5000)) {
                            ArgusThisTCPsrc->status |= ARGUS_OUTOFORDER;
                         } else
                         if (ArgusThisTCPsrc->winbytes > ((maxseq - 1) - ArgusThisTCPdst->ack)) {
