@@ -1,6 +1,6 @@
 /*
  * Argus Software.  Argus files - Udt protocol processing
- * Copyright (c) 2000-2015 QoSient, LLC
+ * Copyright (c) 2000-2020 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,12 +19,6 @@
  *
  */
 
-/* 
- * $Id: //depot/argus/argus/argus/ArgusUdt.c#10 $
- * $DateTime: 2015/06/29 16:17:25 $
- * $Change: 3027 $
- */
-
 #ifdef HAVE_CONFIG_H
 #include "argus_config.h"
 #endif
@@ -41,7 +35,6 @@
 #include <ArgusModeler.h>
 
 #include <argus/bootp.h>
-struct bootp *bp;
 
 struct ArgusSystemFlow *
 ArgusCreateUDTFlow (struct ArgusModelerStruct *model, struct udt_header *udt)
