@@ -1,6 +1,6 @@
 /*
  * Argus Software.  Argus files - main argus processing
- * Copyright (c) 2000-2015 QoSient, LLC
+ * Copyright (c) 2000-2020 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,14 +19,8 @@
  *
  */
 
-/* 
- * $Id: //depot/argus/argus/argus/argus.c#101 $
- * $DateTime: 2015/07/02 10:42:46 $
- * $Change: 3030 $
- */
-
 /*
- * argus - Audit Record Generation and Utilization System
+ * argus.c - Audit Record Generation and Utilization System
  *
  * written by Carter Bullard
  * QoSient LLC
@@ -80,6 +74,7 @@ int ArgusDaemon = 0;
 pthread_attr_t attrbuf, *ArgusAttr = &attrbuf;
 #endif
 
+static void ArgusShutDown (void);
 
 void
 usage(void)
@@ -184,7 +179,7 @@ char *
 ArgusCreatePIDFile (struct ArgusSourceStruct *src, char *pidpath, char *appname)
 {
    FILE *fd;
-   char pidstrbuf[128], *pidstr = pidstrbuf;
+   char pidstrbuf[128], *pidstr;
    char *retn = NULL, *dev = NULL, *devstr = NULL;
    int i, pid;
    struct stat statbuf;
@@ -197,7 +192,9 @@ ArgusCreatePIDFile (struct ArgusSourceStruct *src, char *pidpath, char *appname)
    ArgusDebug (1, "ArgusCreatePIDFile(%s, %s) pidpath is %s\n", pidpath, appname, pidpath);
 #endif 
 
-   if ((appname != NULL) && ((dev = getArgusDevice(src)) != NULL) && (pidpath != NULL)) {
+   dev = getArgusDevice(src);
+
+   if ((appname != NULL) && dev != NULL && (pidpath != NULL)) {
       if ((devstr = strrchr(dev, (int)'/')) != NULL)
          devstr++;
       else
@@ -257,6 +254,9 @@ ArgusCreatePIDFile (struct ArgusSourceStruct *src, char *pidpath, char *appname)
 #endif 
    }
 
+   if (dev != NULL)
+      free(dev); /* allocated by strdup in getArgusDevice() */
+
 #ifdef ARGUSDEBUG
    ArgusDebug (1, "ArgusCreatePIDFile(%s, %s) returning %s\n", pidpath, appname, retn);
 #endif 
@@ -381,7 +381,7 @@ main (int argc, char *argv[])
 
    optind = 1, opterr = 0;
 
-   while ((op = getopt (argc, argv, "AbB:c:CdD:e:fF:g:i:JmM:N:OP:pRr:S:s:tT:u:U:w:XZh")) != EOF) {
+   while ((op = getopt (argc, argv, "AbB:c:CdD:e:fF:g:i:JlmM:N:OP:pRr:S:s:tT:u:U:w:XZh")) != EOF) {
       switch (op) {
          case 'A': setArgusAflag(ArgusModel, 1); break;
          case 'b': setArgusbpflag (ArgusSourceTask, 1); break;
@@ -413,6 +413,7 @@ main (int argc, char *argv[])
 
          case 'i': {
             char Istr[1024], *Iptr = Istr;
+            size_t slen;
 
             if (!commandlinei++)
                clearArgusDevice(ArgusSourceTask);
@@ -441,11 +442,17 @@ main (int argc, char *argv[])
 
             } while (optarg && (*optarg != '-'));
 
+            /* remove trailing space */
+            slen = strlen(Istr);
+            if (slen > 0 && Istr[slen-1] == ' ')
+               Istr[slen-1] = '\0';
+
             setArgusDevice (ArgusSourceTask, Istr, ARGUS_LIVE_DEVICE, 0);
             break;
          }
 
          case 'J': setArgusGenerateTime  (ArgusModel, 1); break;
+         case 'l': setArgusListInterfaces  (ArgusSourceTask, 1); break;
          case 'm': setArgusmflag (ArgusModel, 1); break;
          case 'M': setArgusMarReportInterval (ArgusOutputTask, optarg); break;
          case 'N': {
@@ -556,6 +563,7 @@ main (int argc, char *argv[])
    setArgusArgv   (ArgusSourceTask, argv);
    setArgusOptind (ArgusSourceTask, optind);
    setArgusCmdBuf (ArgusSourceTask);
+
    if (ArgusSourceTask->ArgusCmdBuf != NULL)
       ArgusSourceTask->ArgusInputFilter = strdup(ArgusSourceTask->ArgusCmdBuf);
 
@@ -678,7 +686,7 @@ main (int argc, char *argv[])
    ArgusDebug (1, "main() ArgusSourceProcess returned: shuting down");
 #endif
 
-   ArgusShutDown(0);
+   ArgusShutDown();
 
 #ifdef HAVE_SYSLOG
    closelog();
@@ -808,82 +816,63 @@ char *ArgusSignalTable [] = { "Normal Shutdown",
 };
 
 int ArgusShutDownFlag = 0;
+int ArgusShutDownSig = 0;
 
 #if defined(HAVE_BACKTRACE)
 #include <execinfo.h>
 #endif
 
+void
+ArgusBacktrace (void)
+{
+#if defined(HAVE_BACKTRACE)
+   void* callstack[128];
+   int i, frames = backtrace(callstack, 128);
+   char** strs = backtrace_symbols(callstack, frames);
+
+   for (i = 0; i < frames; ++i) {
+      ArgusLog(LOG_WARNING, "%s", strs[i]);
+   }
+   free(strs);
+#endif
+}
+
 void
 ArgusScheduleShutDown (int sig)
 {
    ArgusShutDownFlag++;
+   ArgusSourceTask->status |= ARGUS_SHUTDOWN;
 
 #ifdef ARGUSDEBUG
-#if defined(HAVE_BACKTRACE)
    if (Argusdflag > 1) {
-      void* callstack[128];
-      int i, frames = backtrace(callstack, 128);
-      char** strs = backtrace_symbols(callstack, frames);
-
       ArgusLog(LOG_WARNING, "ArgusScheduleShutDown(%d)", sig);
-
-      for (i = 0; i < frames; ++i) {
-         ArgusLog(LOG_WARNING, "%s", strs[i]);
-      }
-      free(strs);
+      ArgusBacktrace();
    }
-#endif
 
+   ArgusShutDownSig = sig;
    ArgusDebug (1, "ArgusScheduleShutDown(%d)\n", sig);
 #endif 
 }
 
-void
-ArgusShutDown (int sig)
+static void
+ArgusShutDown (void)
 {
-   ArgusShutDownFlag++;
-
 #if defined(ARGUSDEBUG)
-#if defined(HAVE_BACKTRACE)
    if (Argusdflag > 1) {
-      void* callstack[128];
-      int i, frames = backtrace(callstack, 128);
-      char** strs = backtrace_symbols(callstack, frames);
-
-      ArgusLog(LOG_WARNING, "ArgusShutDown(%d)", sig);
-
-      for (i = 0; i < frames; ++i) {
-         ArgusLog(LOG_WARNING, "%s", strs[i]);
-      }
-      free(strs);
+      ArgusLog(LOG_WARNING, "ArgusShutDown(%d)", ArgusShutDownSig);
+      ArgusBacktrace();
    }
 #endif
-#endif
 
 
-   if (sig < 0) {
-#ifdef ARGUSDEBUG
-      ArgusDebug (1, "ArgusShutDown(ArgusError)\n");
-#endif 
-      exit(0);
-   }
-
 #ifdef ARGUSDEBUG
    if (Argusdflag >= 1)
       fprintf(stderr, "\n");
 
-   ArgusDebug (1, "ArgusShutDown(%s)\n\n", ArgusSignalTable[sig]);
+   ArgusDebug (1, "ArgusShutDown(%s)\n\n", ArgusSignalTable[ArgusShutDownSig]);
 #endif 
 
-   if (!(ArgusShutDownStarted++)) {
-      ArgusComplete ();
-
-   } else {
-#ifdef ARGUSDEBUG
-   ArgusDebug (2, "ArgusShutDown() returning\n");
-#endif 
-      return;
-   }
+   ArgusComplete ();
 
    if (ArgusPidFile)
       unlink (ArgusPidFile);
@@ -899,8 +888,6 @@ ArgusShutDown (int sig)
 #ifdef ARGUSDEBUG
    ArgusDebug (1, "ArgusShutDown()\n");
 #endif 
-
-   exit(0);
 }
 
 
@@ -1380,6 +1367,8 @@ ArgusParseResourceFile (struct ArgusModelerStruct *model, char *file)
                         case ARGUS_FLOW_KEY: {
                            char *tok = NULL;
 
+                           setArgusFlowKey (model, 0);
+
                            while ((tok = strtok(optarg, " +\t")) != NULL) {
                               if (!(strncasecmp(tok, "CLASSIC_5_TUPLE", 14)))
                                  setArgusFlowKey (model, ARGUS_FLOW_KEY_CLASSIC5TUPLE);
@@ -1619,6 +1608,8 @@ clearArgusConfiguration (struct ArgusModelerStruct *model)
    setArgusCaptureFlag (ArgusSourceTask, 0);
    setArgusAflag(model, 0);
    setArgusTimeReport(model, 0);
+   setArgusFlowKey (model, ARGUS_FLOW_KEY_CLASSIC5TUPLE);
+   setArgusFlowType(model, ARGUS_BIDIRECTIONAL);
 
    if (ArgusSourceTask->ArgusWriteOutPacketFile) {
       if (ArgusSourceTask->ArgusPcapOutFile != NULL) {
@@ -1763,7 +1754,7 @@ void
 setArgusEventDataRecord (char *ptr)
 {
    struct ArgusEventRecordStruct *event = NULL;
-   char *sptr, *method = NULL, *file = NULL;
+   char *sptr = NULL, *method = NULL, *file = NULL;
    char *tok = NULL, *pp = NULL, *tptr = NULL;
    int ind = 0, interval, elem = 0;
 
@@ -1775,17 +1766,20 @@ setArgusEventDataRecord (char *ptr)
 
    if (ptr) {
       int i;
-      sptr = strdup(ptr);
-      while ((tok = strtok(sptr, ":")) != NULL) {
+
+      if ((sptr = strdup(ptr)) != NULL)
+         tok = strtok(sptr, ":");
+
+      while (tok != NULL) {
          switch (ind++) {
             case 0:   
-               method = tok;
+               method = strdup(tok);
                if (!((strncmp(method, "file", 4) == 0) || (strncmp(method, "prog", 4) == 0)))
                   ArgusLog (LOG_ERR, "setArgusEventDataRecord, syntax error %s\n", ptr);
                elem++;
                break;
             case 1:
-               file = tok; elem++;
+               file = strdup(tok); elem++;
                break;
             case 2:
                interval = strtol(tok, (char **)&tptr, 10);
@@ -1806,7 +1800,7 @@ setArgusEventDataRecord (char *ptr)
                elem++;
                break;
             case 3:
-               pp = tok;
+               pp = strdup(tok);
                if (!((strncmp(pp, "compress", 8) == 0) || (strncmp(pp, "compress2", 9) == 0)))
                   ArgusLog (LOG_ERR, "setArgusEventDataRecord, syntax error %s\n", ptr);
                elem++;
@@ -1815,24 +1809,26 @@ setArgusEventDataRecord (char *ptr)
                ArgusLog (LOG_ERR, "setArgusEventDataRecord, syntax error %s\n", ptr);
                break;
          }
-         sptr = NULL;
+         tok = strtok(NULL, ":");
       }
 
       if (elem < 3)
          ArgusLog (LOG_ERR, "setArgusEventDataRecord, syntax error %s\n", ptr);
 
-      free (sptr);
+      if (sptr)
+         free (sptr);
       
       if ((event = (struct ArgusEventRecordStruct *) ArgusCalloc (1, sizeof (*event))) != NULL) {
          event->entry    = strdup(ptr);
-         event->method   = strdup(method);
-         event->filename = strdup(file);
+         event->method   = method;
+         event->filename = file;
          event->interval = interval;
          if (pp != NULL) {
             if (!(strncmp(pp, "compress", 8)))
                event->status |= ARGUS_ZLIB_COMPRESS;
             if (!(strncmp(pp, "compress2", 9)))
                event->status |= ARGUS_ZLIB_COMPRESS2;
+            free (pp);
          }
   
          ArgusPushFrontList(ArgusEventsTask->ArgusEventsList, (struct ArgusListRecord *) event, ARGUS_LOCK);
