@@ -1,6 +1,6 @@
 /*
  * Argus Software
- * Copyright (c) 2000-2015 QoSient, LLC
+ * Copyright (c) 2000-2020 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -60,11 +60,6 @@
  *
  */
 
-/* 
- * $Id: //depot/argus/argus/common/argus_filter.c#24 $
- * $DateTime: 2015/04/06 10:38:44 $
- * $Change: 2973 $
- */
 
 #ifdef HAVE_CONFIG_H
 #include "argus_config.h"
@@ -3168,10 +3163,11 @@ nff_dump(struct nff_program *p, char *buf, int buflen, int option)
       return ;
    }
    if (option > 1) {
-      for (i = 0; i < n; ++insn, ++i)
+      for (i = 0; i < n; ++insn, ++i) {
          slen = strlen(buf);
          snprintf(&buf[slen], buflen - slen, "{ 0x%x, %d, %d, 0x%08llx },\n",
                 insn->code, insn->jt, insn->jf, insn->data.k);
+      }
       return;
    }
    for (i = 0; i < n; ++insn, ++i) {
