@@ -1,6 +1,6 @@
 /*
  * Argus Software Common include files -  parsing
- * Copyright (c) 2000-2015 QoSient, LLC
+ * Copyright (c) 2000-2020 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -293,7 +293,6 @@ int check_time_format (struct tm *tm, char *str);
 int parseTime (struct tm *, struct tm *, char *);
 
 #if defined(_LITTLE_ENDIAN)
-void ArgusNtoH (struct ArgusRecord *argus);
 void ArgusHtoN (struct ArgusRecord *argus);
 #endif
 
@@ -496,7 +495,6 @@ extern int check_time_format (struct tm *tm, char *str);
 extern int parseTime (struct tm *, struct tm *, char *);
 
 #if defined(_LITTLE_ENDIAN)
-extern void ArgusNtoH (struct ArgusRecord *argus);
 extern void ArgusHtoN (struct ArgusRecord *argus);
 #endif
 
